=====
Usage
=====

`pygmm` is used within Python scripts. Here is a simple example of plotting the
influence of :math:`V_{s30}` on the Chiou & Youngs (2014) :cite:`chiou14` model:

.. plot:: ../examples/example-1.py
    :include-source:
